@@ -1,4 +1,6 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
+"No file provided for import" => "未提供导入文件",
 "Unsupported file type for import" => "不支持导入的文件类型",
 "Bookmarks" => "书签",
 "Tags" => "标签",
@@ -6,6 +8,7 @@
 "Edit bookmark" => "编辑书签",
 "Are you sure you want to remove this tag from every entry?" => "确定要从所有条目中移除此标签？",
 "Warning" => "警告",
+"Import error" => "导入错误",
 "Import completed successfully." => "导入成功完成。",
 "Uploading..." => "上传中……",
 "Bookm." => "书签",
@@ -18,8 +21,8 @@
 "Delete" => "删除",
 "Edit" => "编辑",
 "Cancel" => "取消",
-"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "拖曳此处到您的浏览器书签处，点击可以将网页快速添加到书签中。",
-"Read later" => "稍后阅读",
+"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "拖曳此处到您的浏览器书签处，点击可以将网页快速增加到书签中。",
+"Add to ownCloud" => "增加到 ownCloud",
 "Address" => "地址",
 "Add" => "增加",
 "Related Tags" => "相关标签",
@@ -31,3 +34,4 @@
 "Export" => "导出",
 "Import" => "导入"
 );
+$PLURAL_FORMS = "nplurals=1; plural=0;";
