@@ -24,9 +24,6 @@
 "Today" => "ယနေ့",
 "Download" => "ဒေါင်းလုတ်",
 "Edit calendar" => "ပြက္ခဒိန်ကိုပြင်မည်",
-"Calendar color" => "ပြက္ခဒိန်အရောင်",
-"Submit" => "ထည့်သွင်းမည်",
-"Cancel" => "ပယ်ဖျက်မည်",
 "Title of the Event" => "ပွဲ၏ခေါင်းစဉ်",
 "Location" => "တည်နေရာ",
 "Description" => "ဖော်ပြချက်",
