@@ -6,9 +6,9 @@
 "Wrong calendar" => "Verkeerde agenda",
 "You do not have the permissions to edit this event." => "U heeft geen permissie om deze gebeurtenis te bewerken.",
 "The file contained either no events or all events are already saved in your calendar." => "Het bestand bevat geen gebeurtenissen of alle gebeurtenissen worden al in uw agenda bewaard.",
-"events has been saved in the new calendar" => "De gebeurtenissen worden in de nieuwe agenda bewaard",
+"events have been saved in the new calendar" => "afspraken zijn opgeslagen in de nieuwe agenda",
 "Import failed" => "import is gefaald",
-"events has been saved in your calendar" => "de gebeurtenissen zijn in uw agenda opgeslagen ",
+"events have been saved in your calendar" => "afspraken zijn opgeslagen in je agenda",
 "New Timezone:" => "Nieuwe tijdszone:",
 "Timezone changed" => "Tijdzone is veranderd",
 "Invalid request" => "Ongeldige aanvraag",
@@ -16,16 +16,14 @@
 "Deletion failed" => "Verwijderen mislukt",
 "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
 "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
-"user" => "gebruiker",
 "group" => "groep",
-"Editable" => "Te wijzigen",
-"Shareable" => "Te delen",
-"Deletable" => "Verwijderbaar",
+"can edit" => "kan wijzigen",
+"can share" => "kan delen",
 "ddd" => "ddd",
 "ddd M/d" => "ddd d.M",
 "dddd M/d" => "dddd d.M",
 "MMMM yyyy" => "MMMM yyyy",
-"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d[ MMM][ yyyy]{ '&#8212;' d MMM yyyy}",
+"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, d. MMM yyyy",
 "Sunday" => "Zondag",
 "Monday" => "Maandag",
@@ -75,17 +73,18 @@
 "To Time" => "Eindtijd",
 "The event ends before it starts" => "De gebeurtenis eindigt voor het begin",
 "There was a database fail" => "Er was een databasefout",
+"Interval is not valid. It must be a positive integer!" => "Interval is niet geldig. Het moet een positief, geheel getal zijn.",
 "Birthday" => "Verjaardag",
 "Business" => "Zakelijk",
 "Call" => "Bellen",
 "Clients" => "Klanten",
-"Deliverer" => "Leverancier",
+"Deliverer" => "Verantwoordelijke",
 "Holidays" => "Vakantie",
 "Ideas" => "Ideeën",
 "Journey" => "Reis",
 "Jubilee" => "Jubileum",
 "Meeting" => "Vergadering",
-"Other" => "Ander",
+"Other" => "Overig",
 "Personal" => "Persoonlijk",
 "Projects" => "Projecten",
 "Questions" => "Vragen",
@@ -96,11 +95,12 @@
 "You do not have the permissions to delete this calendar." => "U heeft geen permissie om deze agenda te verwijderen.",
 "You do not have the permissions to add to this calendar." => "U heeft geen permissie om deze agenda toe te voegen.",
 "You do not have the permissions to add events to this calendar." => "U heeft geen permissie om gebeurtenissen aan deze agenda toe te voegen.",
+"You cannot add non-public events to a shared calendar." => "U kunt geen besloten afspraken in een gedeelde agenda opnemen.",
 "You do not have the permissions to delete this event." => "U heeft geen permissie om deze gebeurtenis te verwijderen.",
 "Busy" => "Bezig",
-"Public" => "Openbaar",
-"Private" => "Privé",
-"Confidential" => "Vertrouwelijk",
+"Show full event" => "Toon gehele gebeurtenis",
+"Show only busy" => "Toon alleen bezig",
+"Hide event" => "Verberg gebeurtenis",
 "Does not repeat" => "Geen",
 "Daily" => "Dagelijks",
 "Weekly" => "Wekelijks",
@@ -124,47 +124,48 @@
 "by yearday(s)" => "volgens jaardag(en)",
 "by weeknumber(s)" => "volgens weeknummer(s)",
 "by day and month" => "per dag en maand",
+"Contact birthdays" => "Verjaardagen contactpersonen",
 "Date" => "Datum",
 "Cal." => "Cal.",
+"Day" => "Dag",
 "Week" => "Week",
 "Month" => "Maand",
-"List" => "Lijst",
 "Today" => "Vandaag",
-"Settings" => "Instellingen",
-"Your calendars" => "Uw agenda's",
 "CalDav Link" => "CalDav Link",
+"Timezone" => "Tijdzone",
+"Update timezone automatically" => "Werk de tijdzone automatisch bij",
+"Time format" => "Tijd formaat",
+"24h" => "24uur",
+"12h" => "12uur",
+"Start week on" => "Begin de week op",
+"Cache" => "Cache",
+"Clear cache for repeating events" => "Leeg cache voor repeterende gebeurtenissen",
+"Primary CalDAV address" => "Primair CalDAV adres",
+"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adres",
 "Share Calendar" => "Deel kalender",
 "Download" => "Download",
 "Edit" => "Bewerken",
 "Delete" => "Verwijderen",
 "New calendar" => "Nieuwe agenda",
 "Edit calendar" => "Bewerk agenda",
-"Displayname" => "Weergavenaam",
-"Active" => "Actief",
-"Calendar color" => "Agenda kleur",
-"Save" => "Opslaan",
-"Submit" => "Opslaan",
-"Cancel" => "Annuleren",
-"Edit an event" => "Bewerken van een afspraak",
-"Export" => "Exporteren",
+"Edit event" => "Bewerk gebeurtenis",
+"Save event" => "Bewaar gebeurtenis",
+"Delete event" => "Verwijder gebeurtenis",
 "Eventinfo" => "Gebeurtenisinformatie",
 "Repeating" => "Herhaling",
 "Alarm" => "Alarm",
 "Attendees" => "Deelnemers",
 "Share" => "Delen",
 "Title of the Event" => "Titel van de afspraak",
-"Category" => "Categorie",
-"Separate categories with commas" => "Gescheiden door komma's",
-"Edit categories" => "Wijzig categorieën",
-"Access Class" => "Toegangsklasse",
+"from" => "van",
+"to" => "naar",
 "All Day Event" => "Hele dag",
-"From" => "Van",
-"To" => "Aan",
 "Advanced options" => "Geavanceerde opties",
 "Location" => "Locatie",
-"Location of the Event" => "Locatie van de afspraak",
+"Categories (separate by comma)" => "Categorieën (commagescheiden)",
+"Edit categories" => "Wijzig categorieën",
 "Description" => "Beschrijving",
-"Description of the Event" => "Beschrijving van de gebeurtenis",
+"Export event" => "Exporteer gebeurtenis",
 "Repeat" => "Herhaling",
 "Advanced" => "Geavanceerd",
 "Select weekdays" => "Selecteer weekdagen",
@@ -177,6 +178,7 @@
 "Interval" => "Interval",
 "End" => "Einde",
 "occurrences" => "gebeurtenissen",
+"Visibility to people shared with" => "Zichtbaar voor alle personen waarmee wordt gedeeld",
 "create a new calendar" => "Maak een nieuw agenda",
 "Import a calendar file" => "Importeer een agenda bestand",
 "Please choose a calendar" => "Kies een agenda",
@@ -187,29 +189,19 @@
 "Import" => "Importeer",
 "Close Dialog" => "Sluit venster",
 "Create a new event" => "Maak een nieuwe afspraak",
-"Share with:" => "Deel met:",
-"Shared with" => "Gedeeld met",
+"Create event" => "Creëer gebeurtenis",
+"Share with user or group" => "Delen met gebruiker of groep",
 "Unshare" => "Stop met delen",
-"Nobody" => "Niemand",
+"Not shared with anyone" => "Met niemand gedeeld",
+"Send Email" => "Versturen e-mail",
 "Shared via calendar" => "Gedeeld via agenda",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "Let op: acties op gebeurtenissen die gedeeld zijn via een agenda, hebben effect op de gehele agenda deling",
+"Not shared with anyone via calendar" => "Niet met iemand gedeeld via de kalender",
 "View an event" => "Bekijk een gebeurtenis",
+"Category" => "Categorie",
 "No categories selected" => "Geen categorieën geselecteerd",
-"of" => "van",
+"%s of %s" => "%s van %s",
+"Access Class" => "Toegangsklasse",
+"From" => "Van",
 "at" => "op",
-"General" => "Algemeen",
-"Timezone" => "Tijdzone",
-"Update timezone automatically" => "Werk de tijdzone automatisch bij",
-"Time format" => "Tijd formaat",
-"24h" => "24uur",
-"12h" => "12uur",
-"Start week on" => "Begin de week op",
-"Cache" => "Cache",
-"Clear cache for repeating events" => "Leeg cache voor repeterende gebeurtenissen",
-"URLs" => "URLs",
-"Calendar CalDAV syncing addresses" => "Agenda CalDAV synchronisatie adres",
-"more info" => "meer informatie",
-"Primary address (Kontact et al)" => "Primary adres (voor Kontact en dergelijke)",
-"iOS/OS X" => "iOS/OS X",
-"Read only iCalendar link(s)" => "Alleen lezen iCalendar link(en)"
+"To" => "Aan"
 );
