@@ -6,24 +6,18 @@
 "Wrong calendar" => "Calendièr pas corrècte",
 "You do not have the permissions to edit this event." => "Sias pas permés d'editar aqueste eveniment.",
 "The file contained either no events or all events are already saved in your calendar." => "Lo fichièr contenguèt siá pas d'eveniments o totes los eveniments son ja enregistrats dins ton calendièr.",
-"events has been saved in the new calendar" => "eveniments que son estats enregistrats dins un calendièr novèl",
 "Import failed" => "Fracàs d'importacion",
-"events has been saved in your calendar" => "eveniments que son estats enregistrats dins lo calendièr teu",
 "New Timezone:" => "Zona novèla :",
 "Timezone changed" => "Zona cambiada",
 "Invalid request" => "Demanda invalida",
 "Calendar" => "Calendièr",
 "Deletion failed" => "Fracàs d'escafatge",
-"user" => "usancièr",
 "group" => "grop",
-"Editable" => "Editable",
-"Shareable" => "Partejador",
-"Deletable" => "Escafable",
+"can edit" => "pòt modificar",
 "ddd" => "jjj",
 "ddd M/d" => "jjj M/j",
 "dddd M/d" => "jjjj M/j",
 "MMMM yyyy" => "MMMM aaaa",
-"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM j[ aaaa]{ '&#8212;'[ MMM] j aaaa}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
 "Sunday" => "Dimenge",
 "Monday" => "Diluns",
@@ -121,42 +115,33 @@
 "Cal." => "Cal.",
 "Week" => "Setmana",
 "Month" => "Mes",
-"List" => "Tièra",
 "Today" => "Uèi",
-"Settings" => "Configuracion",
-"Your calendars" => "Los calendièrs vòstres",
 "CalDav Link" => "Ligam CalDav",
+"Timezone" => "Zona",
+"Update timezone automatically" => "Zona mesa a jorn automaticament",
+"Time format" => "Format de l'ora",
+"24h" => "24h",
+"12h" => "12h",
+"Start week on" => "La setmana comença lo",
+"Cache" => "Cache",
+"Clear cache for repeating events" => "Voida lo cache per los eveniments repetitius",
 "Share Calendar" => "Parteja lo calendièr",
 "Download" => "Avalcargar",
 "Edit" => "Editar",
 "Delete" => "Escafa",
 "New calendar" => "Calendièr novèl",
 "Edit calendar" => "Edita calendièr",
-"Displayname" => "Nom afichat",
-"Active" => "Actiu",
-"Calendar color" => "Color de calendièr",
-"Save" => "Enregistra",
-"Submit" => "Sosmetre",
-"Cancel" => "Anulla",
-"Edit an event" => "Edita un eveniment",
-"Export" => "Exporta",
 "Eventinfo" => "Eventinfo",
 "Repeating" => "Al tornar far",
 "Alarm" => "Alarma",
 "Attendees" => "Convidats",
 "Share" => "Parteja",
 "Title of the Event" => "Títol del eveniment",
-"Category" => "Categoria",
-"Separate categories with commas" => "Destria categorias amb virgulas",
-"Edit categories" => "Edita categorias",
 "All Day Event" => "Eveniment de cada jorn",
-"From" => "De",
-"To" => "Per",
 "Advanced options" => "Opcions avançadas",
 "Location" => "Plaça",
-"Location of the Event" => "Plaça del eveniment",
+"Edit categories" => "Edita categorias",
 "Description" => "Descripcion",
-"Description of the Event" => "Descripcion del eveniment",
 "Repeat" => "Torna far",
 "Advanced" => "Avançat",
 "Select weekdays" => "Selecciona los jorns de setmana",
@@ -178,29 +163,12 @@
 "Import" => "Importa",
 "Close Dialog" => "Tampa lo dialòg",
 "Create a new event" => "Crea un eveniment nòu",
-"Share with:" => "Parteja amb :",
-"Shared with" => "Partejat amb :",
 "Unshare" => "Pas partejador",
-"Nobody" => "degun",
 "Shared via calendar" => "Partejat tras calendièr",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "AVÍS:  las actions suls eveniments partejats tras calendièr cambiaràn los partatge  de calendièr complet.",
 "View an event" => "Espiar un eveniment",
+"Category" => "Categoria",
 "No categories selected" => "Cap de categorias seleccionadas",
-"of" => "de",
+"From" => "De",
 "at" => "a",
-"General" => "General",
-"Timezone" => "Zona",
-"Update timezone automatically" => "Zona mesa a jorn automaticament",
-"Time format" => "Format de l'ora",
-"24h" => "24h",
-"12h" => "12h",
-"Start week on" => "La setmana comença lo",
-"Cache" => "Cache",
-"Clear cache for repeating events" => "Voida lo cache per los eveniments repetitius",
-"URLs" => "URLs",
-"Calendar CalDAV syncing addresses" => "Calendar CalDAV syncing addresses",
-"more info" => "mai d'entresenhes",
-"Primary address (Kontact et al)" => "Adreiças primarias (Kontact et al)",
-"iOS/OS X" => "iOS/OS X",
-"Read only iCalendar link(s)" => "Ligam(s) iCalendar en lectura sola"
+"To" => "Per"
 );
