@@ -6,9 +6,7 @@
 "Wrong calendar" => "Sai lịch",
 "You do not have the permissions to edit this event." => "Bạn không có quyền chỉnh sửa sự kiện này.",
 "The file contained either no events or all events are already saved in your calendar." => "Các tập tin có hay không có sự kiện hoặc tất cả các sự kiện đã được lưu trong lịch của bạn.",
-"events has been saved in the new calendar" => "sự kiện đã được lưu vào lịch mới.",
 "Import failed" => "Nhập vào thất bại",
-"events has been saved in your calendar" => "sự kiện đã dược lưu vào lịch",
 "New Timezone:" => "Múi giờ mới :",
 "Timezone changed" => "Thay đổi múi giờ",
 "Invalid request" => "Yêu cầu không hợp lệ",
@@ -16,16 +14,14 @@
 "Deletion failed" => "Xóa thất bại",
 "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
 "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
-"user" => "người dùng",
 "group" => "nhóm",
-"Editable" => "Có thể chỉnh sửa",
-"Shareable" => "Có thể chia sẽ",
-"Deletable" => "Có thể xóa",
+"can edit" => "có thể chỉnh sửa",
+"can share" => "có thể chia sẽ",
 "ddd" => "ddd",
 "ddd M/d" => "ddd M/d",
 "dddd M/d" => "dddd M/d",
 "MMMM yyyy" => "MMMM yyyy",
-"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
+"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
 "Sunday" => "Chủ nhật",
 "Monday" => "Thứ 2",
@@ -96,11 +92,12 @@
 "You do not have the permissions to delete this calendar." => "Bạn không có quyền xóa lịch này",
 "You do not have the permissions to add to this calendar." => "Bạn không có quyền thêm lịch này",
 "You do not have the permissions to add events to this calendar." => "Bạn không có quyền thêm các sự kiện vào lịch này.",
+"You cannot add non-public events to a shared calendar." => "Bạn không thể thêm sự kiện không phải công cộng để chia sẻ lịch.",
 "You do not have the permissions to delete this event." => "Bạn không có quyền xóa sự kiện này.",
 "Busy" => "Bận",
-"Public" => "Công khai",
-"Private" => "Riêng tư",
-"Confidential" => "Mật",
+"Show full event" => "Hiển thị đầy đủ sự kiện",
+"Show only busy" => "Hiển thị bận",
+"Hide event" => "Ẩn sự kiện",
 "Does not repeat" => "Không lặp lại",
 "Daily" => "Hàng ngày",
 "Weekly" => "Hàng tuần",
@@ -124,47 +121,46 @@
 "by yearday(s)" => "Theo ngày trong năm",
 "by weeknumber(s)" => "Theo số tuần",
 "by day and month" => "Theo ngày, tháng",
+"Contact birthdays" => "Danh sách sinh nhật",
 "Date" => "Ngày",
 "Cal." => "Cal.",
+"Day" => "Ngày",
 "Week" => "Tuần",
 "Month" => "Tháng",
-"List" => "Danh sách",
 "Today" => "Hôm nay",
-"Settings" => "Tùy chỉnh",
-"Your calendars" => "Lịch của bạn",
 "CalDav Link" => "Liên kết CalDav ",
+"Timezone" => "Múi giờ",
+"Update timezone automatically" => "Tự động cập nhập múi giờ",
+"Time format" => "Định dạng thời gian",
+"24h" => "24h",
+"12h" => "12h",
+"Start week on" => "Ngày bắt đầu trong tuần",
+"Cache" => "Bộ đệm",
+"Clear cache for repeating events" => "Xóa bộ nhớ đệm cho các sự kiện trùng nhau",
 "Share Calendar" => "Chia sẻ lịch",
 "Download" => "Tải về",
 "Edit" => "Chỉnh sửa",
 "Delete" => "Xóa",
 "New calendar" => "Lịch mới",
 "Edit calendar" => "sửa Lịch",
-"Displayname" => "Hiển thị tên",
-"Active" => "Kích hoạt",
-"Calendar color" => "Màu lịch",
-"Save" => "Lưu",
-"Submit" => "Xác nhận",
-"Cancel" => "Hủy",
-"Edit an event" => "Sửa sự kiện",
-"Export" => "Xuất ra",
+"Edit event" => "Sửa sự kiện",
+"Save event" => "Lưu sự kiện",
+"Delete event" => "Xóa sự kiện",
 "Eventinfo" => "Thông tin sự kiện",
 "Repeating" => "Lặp",
 "Alarm" => "Nhắc nhở",
 "Attendees" => "Người tham gia",
 "Share" => "Chia sẻ",
 "Title of the Event" => "Tên sự kiện",
-"Category" => "Danh mục",
-"Separate categories with commas" => "Phân cách bởi dấu phẩy",
-"Edit categories" => "Sửa chuyên mục",
-"Access Class" => "Mức truy cập",
+"from" => "từ",
+"to" => "đến",
 "All Day Event" => "Sự kiện trong ngày",
-"From" => "Từ",
-"To" => "Tới",
 "Advanced options" => "Tùy chọn nâng cao",
 "Location" => "Nơi",
-"Location of the Event" => "Nơi tổ chức sự kiện",
+"Categories (separate by comma)" => "Thể loại (phân cách bằng dấu phẩy)",
+"Edit categories" => "Sửa chuyên mục",
 "Description" => "Mô tả",
-"Description of the Event" => "Mô tả sự kiện",
+"Export event" => "Trích xuất sự kiện",
 "Repeat" => "Lặp lại",
 "Advanced" => "Nâng cao",
 "Select weekdays" => "Chọn ngày trong tuần",
@@ -177,6 +173,7 @@
 "Interval" => "Khoảng từ",
 "End" => "Kết thúc",
 "occurrences" => "Sự kiện",
+"Visibility to people shared with" => "Hiển thị với những người chia sẻ",
 "create a new calendar" => "Tạo lịch mới",
 "Import a calendar file" => "Nhập lịch từ tập tin",
 "Please choose a calendar" => "Vui lòng chọn lịch",
@@ -187,29 +184,18 @@
 "Import" => "Nhập vào",
 "Close Dialog" => "Đóng hộp thoại",
 "Create a new event" => "Tạo một sự kiện mới",
-"Share with:" => "Chia sẻ với:",
-"Shared with" => "Đã chia sẻ với",
+"Create event" => "Tạo sự kiện",
+"Share with user or group" => "Chia sẽ với người dùng hoặc nhóm",
 "Unshare" => "Bỏ chia sẻ",
-"Nobody" => "Không ai cả",
+"Not shared with anyone" => "Không chia sẽ với bất cứ ai",
+"Send Email" => "Gửi thư",
 "Shared via calendar" => "Được chia sẻ qua lịch",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "Chú ý: Thao tác trên các sự kiện chia sẻ qua lịch sẽ ảnh hưởng đến việc chia sẻ toàn bộ lịch.",
+"Not shared with anyone via calendar" => "Không chia sẽ với bất cứ ai qua lịch",
 "View an event" => "Xem một sự kiện",
+"Category" => "Danh mục",
 "No categories selected" => "Không danh sách nào được chọn",
-"of" => "của",
+"Access Class" => "Mức truy cập",
+"From" => "Từ",
 "at" => "tại",
-"General" => "Tổng hợp",
-"Timezone" => "Múi giờ",
-"Update timezone automatically" => "Tự động cập nhập múi giờ",
-"Time format" => "Định dạng thời gian",
-"24h" => "24h",
-"12h" => "12h",
-"Start week on" => "Ngày bắt đầu trong tuần",
-"Cache" => "Bộ nhớ đệm",
-"Clear cache for repeating events" => "Xóa bộ nhớ đệm cho các sự kiện lặp đi lặp lại",
-"URLs" => "URLs",
-"Calendar CalDAV syncing addresses" => "Đồng bộ địa chỉ lịch CalDAV",
-"more info" => "thông tin thêm",
-"Primary address (Kontact et al)" => "Địa chỉ chính (Kontact et al) ",
-"iOS/OS X" => "iOS/OS X",
-"Read only iCalendar link(s)" => "Chỉ đọc iCalendar link(s)"
+"To" => "Tới"
 );
