@@ -1,38 +1,51 @@
 <?php $TRANSLATIONS = array(
-"Error (de)activating addressbook." => "Fehler beim (de)aktivéieren vum Adressbuch.",
-"id is not set." => "ID ass net gesat.",
-"No ID provided" => "Keng ID uginn",
-"Error setting checksum." => "Fehler beim setzen vun der Checksum.",
-"No categories selected for deletion." => "Keng Kategorien fir ze läschen ausgewielt.",
-"No address books found." => "Keen Adressbuch fonnt.",
-"No contacts found." => "Keng Kontakter fonnt.",
+"Contacts" => "Kontakter",
+"Ok" => "OK",
+"Cancel" => "Ofbriechen",
+"Save" => "Späicheren",
+"Edit Addressbook" => "Adressbuch editéieren",
+"Error." => "Fehler.",
+"Add group..." => "Grupp bäisetzen...",
+"Select photo" => "Foto auswielen",
+"Add group" => "Grupp bäisetzen",
+"OK" => "OK",
+"# groups" => "# Gruppen",
+"Add" => "Dobäisetzen",
+"All" => "All",
+"Favorites" => "Favoriten",
+"Import" => "Importeieren",
+"Importing..." => "Gett importéiert...",
+"Close" => "Zoumaachen",
+"Unknown error" => "Et ass en onbekannte Fehler opgetrueden",
+"{name}'s Birthday" => "{name} säi Gebuertsdag",
 "Information about vCard is incorrect. Please reload the page." => "Informatioun iwwert vCard ass net richteg. Lued d'Säit wegl nei.",
-"No contact ID was submitted." => "Kontakt ID ass net mat geschéckt ginn.",
-"Error reading contact photo." => "Fehler beim liesen vun der Kontakt Photo.",
-"Error saving temporary file." => "Fehler beim späicheren vum temporäre Fichier.",
-"The loading photo is not valid." => "Déi geluede Photo ass net gülteg.",
-"Contact ID is missing." => "Kontakt ID fehlt.",
-"File doesn't exist:" => "Fichier existéiert net:",
-"Error loading image." => "Fehler beim lueden vum Bild.",
+"No photo path was submitted." => "Et gouf kee Foto-Pfad iwwerdroen.",
+"Error getting PHOTO property." => "Feeler beim Luede vun der PHOTO-Eegeschaft.",
+"Error saving contact." => "Feeler beim Späichere vum Kontakt.",
 "There is no error, the file uploaded with success" => "Keen Feeler, Datei ass komplett ropgelueden ginn",
 "The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Déi ropgelueden Datei ass méi grouss wei d'upload_max_filesize Eegenschaft an der php.ini",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
 "The uploaded file was only partially uploaded" => "Déi ropgelueden Datei ass nëmmen hallef ropgelueden ginn",
 "No file was uploaded" => "Et ass kee Fichier ropgeluede ginn",
 "Missing a temporary folder" => "Et feelt en temporären Dossier",
-"Contacts" => "Kontakter",
-"Error" => "Fehler",
-"Unable to upload your file as it is a directory or has 0 bytes" => "Kann deng Datei net eroplueden well et en Dossier ass oder 0 byte grouss ass.",
-"Upload Error" => "Fehler beim eroplueden",
-"Result: " => "Resultat: ",
-" imported, " => " importéiert, ",
-"Download" => "Download",
-"Edit" => "Editéieren",
-"Delete" => "Läschen",
-"Cancel" => "Ofbriechen",
+"Failed to write to disk" => "Konnt net op den Disk schreiwen",
+"Contact" => "Kontakt",
+"Other" => "Aner",
+"Jabber" => "Jabber",
+"AIM" => "AIM",
+"MSN" => "MSN",
+"Twitter" => "Twitter",
+"GoogleTalk" => "GoogleTalk",
+"Facebook" => "Facebook",
+"XMPP" => "XMPP",
+"ICQ" => "ICQ",
+"Yahoo" => "Yahoo",
+"Skype" => "Skype",
+"QQ" => "QQ",
+"GaduGadu" => "GaduGadu",
+"ownCloud" => "ownCloud",
 "Work" => "Aarbecht",
 "Home" => "Doheem",
-"Other" => "Aner",
 "Mobile" => "GSM",
 "Text" => "SMS",
 "Voice" => "Voice",
@@ -41,36 +54,37 @@
 "Video" => "Video",
 "Pager" => "Pager",
 "Internet" => "Internet",
-"{name}'s Birthday" => "{name} säi Gebuertsdag",
-"Contact" => "Kontakt",
-"Settings" => "Astellungen",
-"Import" => "Import",
-"OK" => "OK",
+"Friends" => "Frënn",
+"Family" => "Famill",
+"Group name" => "Gruppe Numm",
+"Delete" => "Läschen",
 "Groups" => "Gruppen",
-"Close" => "Zoumaachen",
+"Download" => "Download",
+"Email" => "Email",
+"Phone" => "Telefon",
+"Address" => "Adress",
+"Group" => "Grupp",
+"Add new contact" => "Neie Kontakt bäisetzen",
+"Name" => "Numm",
+"First name" => "Virnumm",
 "Additional names" => "Weider Nimm",
+"Last name" => "Famillje Numm",
 "Nickname" => "Spëtznumm",
-"Enter nickname" => "Gëff e Spëtznumm an",
 "Title" => "Titel",
 "Organization" => "Firma",
-"Birthday" => "Gebuertsdag",
-"Add" => "Dobäisetzen",
-"Phone" => "Telefon",
-"Email" => "Email",
-"Address" => "Adress",
+"Birthday" => "Gebuertsdaag",
+"Instant Messaging" => "Instant Messaging",
 "Note" => "Note",
-"Delete contact" => "Kontakt läschen",
+"Web site" => "Web site",
 "Enter phone number" => "Telefonsnummer aginn",
-"Delete phone number" => "Telefonsnummer läschen",
 "View on map" => "Op da Kaart uweisen",
 "City" => "Staat",
 "Country" => "Land",
+"Active" => "Aktiv",
 "Share" => "Deelen",
-"Export" => "Export",
-"more info" => "méi Informatiounen",
-"iOS/OS X" => "iOS/OS X",
-"Addressbooks" => "Adressbicher ",
-"New Address Book" => "Neit Adressbuch",
-"Name" => "Numm",
-"Save" => "Späicheren"
+"Export" => "Exporteieren",
+"CardDAV link" => "CardDav Link",
+"Edit" => "Editéieren",
+"Description" => "Beschreiwung",
+"Password" => "Passwuert"
 );
