@@ -1,7 +1,7 @@
 <?php
 
 /**
- * ownCloud - External plugin
+ * ownCloud - External app
  *
  * @author Frank Karlitschek
  * @copyright 2012 Frank Karlitschek frank@owncloud.org
@@ -16,18 +16,22 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Affero General Public
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-OC::$CLASSPATH['OC_External'] = 'apps/external/lib/external.php';
-OCP\Util::addStyle( 'external', 'style');
+use OCA\External\External;
 
+OCP\Util::addStyle( 'external', 'style');
 OCP\App::registerAdmin('external', 'settings');
 
-$sites = OC_External::getSites();
+$sites = External::getSites();
 for ($i = 0; $i < sizeof($sites); $i++) {
 	OCP\App::addNavigationEntry(
-			array('id' => 'external_index' . ($i + 1), 'order' => 80 + $i, 'href' => OCP\Util::linkTo('external', 'index.php') . '?id=' . ($i + 1), 'icon' => OCP\Util::imagePath('external', 'external.png'), 'name' => $sites[$i][0]));
+			array(
+				'id' => 'external_index' . ($i + 1), 'order' => 80 + $i,
+				'href' => OCP\Util::linkTo('external', 'index.php') . '?id=' . ($i + 1),
+				'icon' => OCP\Util::imagePath('external', 'external.png'),
+				'name' => $sites[$i][0]));
 }
