@@ -21,21 +21,17 @@
 *
 */
 
-// only need filesystem apps
-$RUNTIME_APPTYPES=array('filesystem');
-
-// Init owncloud
-
-
 // Check if we are a user
 OCP\User::checkLoggedIn();
+\OC::$session->close();
 
 $files = $_GET["files"];
 $dir = $_GET["dir"];
 
-if ($files == "Shared" and $dir == "/") {
-	$files = '';
-	$dir = "/Shared";
+$files_list = json_decode($files);
+// in case we get only a single file
+if (!is_array($files_list)) {
+	$files_list = array($files);
 }
 
-OC_Files::get($dir, $files, $_SERVER['REQUEST_METHOD'] == 'HEAD' ? true : false);
+OC_Files::get($dir, $files_list, $_SERVER['REQUEST_METHOD'] == 'HEAD');
