@@ -1,19 +1,26 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
 "There is no error, the file uploaded with success" => "Nema greške, fajl je uspešno poslat",
-"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Poslati fajl prevazilazi direktivu upload_max_filesize iz ",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Poslati fajl prevazilazi direktivu MAX_FILE_SIZE koja je navedena u HTML formi",
 "The uploaded file was only partially uploaded" => "Poslati fajl je samo delimično otpremljen!",
 "No file was uploaded" => "Nijedan fajl nije poslat",
 "Missing a temporary folder" => "Nedostaje privremena fascikla",
 "Files" => "Fajlovi",
+"Share" => "Podeli",
 "Delete" => "Obriši",
+"Rename" => "Preimenij",
+"Error" => "Greška",
 "Name" => "Ime",
 "Size" => "Veličina",
 "Modified" => "Zadnja izmena",
+"_%n folder_::_%n folders_" => array("","",""),
+"_%n file_::_%n files_" => array("","",""),
+"_Uploading %n file_::_Uploading %n files_" => array("","",""),
 "Maximum upload size" => "Maksimalna veličina pošiljke",
-"Upload" => "Pošalji",
+"Save" => "Snimi",
 "Nothing in here. Upload something!" => "Ovde nema ničeg. Pošaljite nešto!",
 "Download" => "Preuzmi",
 "Upload too large" => "Pošiljka je prevelika",
 "The files you are trying to upload exceed the maximum size for file uploads on this server." => "Fajlovi koje želite da pošaljete prevazilaze ograničenje maksimalne veličine pošiljke na ovom serveru."
 );
+$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
