@@ -21,10 +21,6 @@
 *
 */
 
-
-// Init owncloud
-
-
 // Check if we are a user
 OCP\User::checkLoggedIn();
 
@@ -36,7 +32,7 @@ OCP\Util::addscript( "files", "files" );
 $dir = isset( $_GET['dir'] ) ? $_GET['dir'] : '';
 
 $files = array();
-foreach( OC_Files::getdirectorycontent( $dir ) as $i ) {
+foreach( \OC\Files\Filesystem::getDirectoryContent( $dir ) as $i ) {
 	$i["date"] = date( $CONFIG_DATEFORMAT, $i["mtime"] );
 	$files[] = $i;
 }
