@@ -27,29 +27,31 @@ require_once __DIR__ . '/../lib/proxy.php';
 require_once __DIR__ . '/../lib/stream.php';
 require_once __DIR__ . '/../lib/util.php';
 require_once __DIR__ . '/../appinfo/app.php';
-require_once __DIR__ . '/util.php';
 
 use OCA\Encryption;
 
 /**
  * Class Test_Encryption_Proxy
- * @brief this class provide basic proxy app tests
+ * this class provide basic proxy app tests
  */
-class Test_Encryption_Proxy extends \PHPUnit_Framework_TestCase {
+class Test_Encryption_Proxy extends \OCA\Files_Encryption\Tests\TestCase {
 
 	const TEST_ENCRYPTION_PROXY_USER1 = "test-proxy-user1";
 
 	public $userId;
 	public $pass;
 	/**
-	 * @var \OC_FilesystemView
+	 * @var \OC\Files\View
 	 */
 	public $view;     // view in /data/user/files
 	public $rootView; // view on /data/user
 	public $data;
+	public $dataLong;
 	public $filename;
 
 	public static function setUpBeforeClass() {
+		parent::setUpBeforeClass();
+
 		// reset backend
 		\OC_User::clearBackends();
 		\OC_User::useBackend('database');
@@ -65,47 +67,62 @@ class Test_Encryption_Proxy extends \PHPUnit_Framework_TestCase {
 		\OC_FileProxy::register(new OCA\Encryption\Proxy());
 
 		// create test user
-		\Test_Encryption_Util::loginHelper(\Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1, true);
+		self::loginHelper(\Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1, true);
 	}
 
-	function setUp() {
+	protected function setUp() {
+		parent::setUp();
+
 		// set user id
 		\OC_User::setUserId(\Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1);
 		$this->userId = \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1;
 		$this->pass = \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1;
 
 		// init filesystem view
-		$this->view = new \OC_FilesystemView('/'. \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files');
-		$this->rootView = new \OC_FilesystemView('/'. \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 );
+		$this->view = new \OC\Files\View('/'. \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files');
+		$this->rootView = new \OC\Files\View('/'. \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 );
 
 		// init short data
 		$this->data = 'hats';
-		$this->filename = 'enc_proxy_tests-' . uniqid() . '.txt';
+		$this->dataLong = file_get_contents(__DIR__ . '/../lib/crypt.php');
+		$this->filename = 'enc_proxy_tests-' . $this->getUniqueID() . '.txt';
 
 	}
 
 	public static function tearDownAfterClass() {
 		// cleanup test user
 		\OC_User::deleteUser(\Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1);
+
+		\OC_Hook::clear();
+		\OC_FileProxy::clearProxies();
+
+		// Delete keys in /data/
+		$view = new \OC\Files\View('/');
+		$view->rmdir('public-keys');
+		$view->rmdir('owncloud_private_key');
+
+		parent::tearDownAfterClass();
 	}
 
 	/**
 	 * @medium
-	 * @brief test if postFileSize returns the unencrypted file size
+	 * test if postFileSize returns the unencrypted file size
 	 */
 	function testPostFileSize() {
 
-		$this->view->file_put_contents($this->filename, $this->data);
+		$this->view->file_put_contents($this->filename, $this->dataLong);
+		$size = strlen($this->dataLong);
 
 		\OC_FileProxy::$enabled = false;
 
-		$unencryptedSize = $this->view->filesize($this->filename);
+		$encryptedSize = $this->view->filesize($this->filename);
 
 		\OC_FileProxy::$enabled = true;
 
-		$encryptedSize = $this->view->filesize($this->filename);
+		$unencryptedSize = $this->view->filesize($this->filename);
 
-		$this->assertTrue($encryptedSize !== $unencryptedSize);
+		$this->assertTrue($encryptedSize > $unencryptedSize);
+		$this->assertSame($size, $unencryptedSize);
 
 		// cleanup
 		$this->view->unlink($this->filename);
@@ -132,4 +149,42 @@ class Test_Encryption_Proxy extends \PHPUnit_Framework_TestCase {
 
 	}
 
+	/**
+	 * @dataProvider isExcludedPathProvider
+	 */
+	function testIsExcludedPath($path, $expected) {
+		$this->view->mkdir(dirname($path));
+		$this->view->file_put_contents($path, "test");
+
+		$testClass = new DummyProxy();
+
+		$result = $testClass->isExcludedPathTesting($path, $this->userId);
+		$this->assertSame($expected, $result);
+
+		$this->view->deleteAll(dirname($path));
+
+	}
+
+	public function isExcludedPathProvider() {
+		return array(
+			array ('/' . \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files/test.txt', false),
+			array (\Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files/test.txt', false),
+			array ('/files/test.txt', true),
+			array ('/' . \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files/versions/test.txt', false),
+			array ('/' . \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files_versions/test.txt', false),
+			array ('/' . \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/files_trashbin/test.txt', true),
+			array ('/' . \Test_Encryption_Proxy::TEST_ENCRYPTION_PROXY_USER1 . '/file/test.txt', true),
+		);
+	}
+
+}
+
+
+/**
+ * Dummy class to make protected methods available for testing
+ */
+class DummyProxy extends \OCA\Encryption\Proxy {
+	public function isExcludedPathTesting($path, $uid) {
+		return $this->isExcludedPath($path, $uid);
+	}
 }
