@@ -1,25 +1,31 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
+"Please provide a valid Dropbox app key and secret." => "Por favor, proporcioná un secreto y una contraseña válida para la aplicación Dropbox.",
+"External storage" => "Almacenamiento externo",
+"Location" => "Ubicación",
+"Host" => "Servidor",
+"Username" => "Nombre de usuario",
+"Password" => "Contraseña",
+"Share" => "Compartir",
+"URL" => "URL",
 "Access granted" => "Acceso permitido",
 "Error configuring Dropbox storage" => "Error al configurar el almacenamiento de Dropbox",
 "Grant access" => "Permitir acceso",
-"Please provide a valid Dropbox app key and secret." => "Por favor, proporcioná un secreto y una contraseña válida para la aplicación Dropbox.",
 "Error configuring Google Drive storage" => "Error al configurar el almacenamiento de Google Drive",
-"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>Advertencia:</b> El cliente smb (smbclient) no se encuentra instalado. El montado de archivos o ficheros CIFS/SMB no es posible. Por favor pida al administrador de su sistema que lo instale.",
-"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>Advertencia:</b> El soporte de FTP en PHP no se encuentra instalado. El montado de archivos o ficheros FTP no es posible. Por favor pida al administrador de su sistema que lo instale.",
+"Personal" => "Personal",
+"Saved" => "Guardado",
+"Name" => "Nombre",
 "External Storage" => "Almacenamiento externo",
 "Folder name" => "Nombre de la carpeta",
-"External storage" => "Almacenamiento externo",
 "Configuration" => "Configuración",
 "Options" => "Opciones",
-"Applicable" => "Aplicable",
 "Add storage" => "Añadir almacenamiento",
-"None set" => "No fue configurado",
 "All Users" => "Todos los usuarios",
 "Groups" => "Grupos",
 "Users" => "Usuarios",
 "Delete" => "Borrar",
 "Enable User External Storage" => "Habilitar almacenamiento de usuario externo",
-"Allow users to mount their own external storage" => "Permitir a los usuarios montar su propio almacenamiento externo",
 "SSL root certificates" => "certificados SSL raíz",
 "Import Root Certificate" => "Importar certificado raíz"
 );
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
