@@ -22,7 +22,7 @@
 
 namespace OC\Files\Storage;
 
-require_once 'Dropbox/autoload.php';
+require_once __DIR__ . '/../3rdparty/Dropbox/autoload.php';
 
 class Dropbox extends \OC\Files\Storage\Common {
 
@@ -44,12 +44,32 @@ class Dropbox extends \OC\Files\Storage\Common {
 			$this->id = 'dropbox::'.$params['app_key'] . $params['token']. '/' . $this->root;
 			$oauth = new \Dropbox_OAuth_Curl($params['app_key'], $params['app_secret']);
 			$oauth->setToken($params['token'], $params['token_secret']);
-			$this->dropbox = new \Dropbox_API($oauth, 'dropbox');
+			// note: Dropbox_API connection is lazy
+			$this->dropbox = new \Dropbox_API($oauth, 'auto');
 		} else {
 			throw new \Exception('Creating \OC\Files\Storage\Dropbox storage failed');
 		}
 	}
 
+	/**
+	 * @param string $path
+	 */
+	private function deleteMetaData($path) {
+		$path = $this->root.$path;
+		if (isset($this->metaData[$path])) {
+			unset($this->metaData[$path]);
+			return true;
+		}
+		return false;
+	}
+
+	/**
+	 * Returns the path's metadata
+	 * @param string $path path for which to return the metadata
+	 * @param bool $list if true, also return the directory's contents
+	 * @return mixed directory contents if $list is true, file metadata if $list is
+	 * false, null if the file doesn't exist or "false" if the operation failed
+	 */
 	private function getMetaData($path, $list = false) {
 		$path = $this->root.$path;
 		if ( ! $list && isset($this->metaData[$path])) {
@@ -62,24 +82,35 @@ class Dropbox extends \OC\Files\Storage\Common {
 					\OCP\Util::writeLog('files_external', $exception->getMessage(), \OCP\Util::ERROR);
 					return false;
 				}
+				$contents = array();
 				if ($response && isset($response['contents'])) {
-					$contents = $response['contents'];
 					// Cache folder's contents
-					foreach ($contents as $file) {
-						$this->metaData[$path.'/'.basename($file['path'])] = $file;
+					foreach ($response['contents'] as $file) {
+						if (!isset($file['is_deleted']) || !$file['is_deleted']) {
+							$this->metaData[$path.'/'.basename($file['path'])] = $file;
+							$contents[] = $file;
+						}
 					}
 					unset($response['contents']);
+				}
+				if (!isset($response['is_deleted']) || !$response['is_deleted']) {
 					$this->metaData[$path] = $response;
 				}
-				$this->metaData[$path] = $response;
 				// Return contents of folder only
 				return $contents;
 			} else {
 				try {
 					$response = $this->dropbox->getMetaData($path, 'false');
-					$this->metaData[$path] = $response;
-					return $response;
+					if (!isset($response['is_deleted']) || !$response['is_deleted']) {
+						$this->metaData[$path] = $response;
+						return $response;
+					}
+					return null;
 				} catch (\Exception $exception) {
+					if ($exception instanceof \Dropbox_Exception_NotFound) {
+						// don't log, might be a file_exist check
+						return false;
+					}
 					\OCP\Util::writeLog('files_external', $exception->getMessage(), \OCP\Util::ERROR);
 					return false;
 				}
@@ -108,7 +139,7 @@ class Dropbox extends \OC\Files\Storage\Common {
 
 	public function opendir($path) {
 		$contents = $this->getMetaData($path, true);
-		if ($contents) {
+		if ($contents !== false) {
 			$files = array();
 			foreach ($contents as $file) {
 				$files[] = basename($file['path']);
@@ -146,14 +177,6 @@ class Dropbox extends \OC\Files\Storage\Common {
 		return false;
 	}
 
-	public function isReadable($path) {
-		return $this->file_exists($path);
-	}
-
-	public function isUpdatable($path) {
-		return $this->file_exists($path);
-	}
-
 	public function file_exists($path) {
 		if ($path == '' || $path == '/') {
 			return true;
@@ -165,9 +188,9 @@ class Dropbox extends \OC\Files\Storage\Common {
 	}
 
 	public function unlink($path) {
-		$path = $this->root.$path;
 		try {
-			$this->dropbox->delete($path);
+			$this->dropbox->delete($this->root.$path);
+			$this->deleteMetaData($path);
 			return true;
 		} catch (\Exception $exception) {
 			\OCP\Util::writeLog('files_external', $exception->getMessage(), \OCP\Util::ERROR);
@@ -176,10 +199,14 @@ class Dropbox extends \OC\Files\Storage\Common {
 	}
 
 	public function rename($path1, $path2) {
-		$path1 = $this->root.$path1;
-		$path2 = $this->root.$path2;
 		try {
-			$this->dropbox->move($path1, $path2);
+			// overwrite if target file exists and is not a directory
+			$destMetaData = $this->getMetaData($path2);
+			if (isset($destMetaData) && $destMetaData !== false && !$destMetaData['is_dir']) {
+				$this->unlink($path2);
+			}
+			$this->dropbox->move($this->root.$path1, $this->root.$path2);
+			$this->deleteMetaData($path1);
 			return true;
 		} catch (\Exception $exception) {
 			\OCP\Util::writeLog('files_external', $exception->getMessage(), \OCP\Util::ERROR);
@@ -277,7 +304,23 @@ class Dropbox extends \OC\Files\Storage\Common {
 	}
 
 	public function touch($path, $mtime = null) {
-		return false;
+		if ($this->file_exists($path)) {
+			return false;
+		} else {
+			$this->file_put_contents($path, '');
+		}
+		return true;
+	}
+
+	/**
+	 * check if curl is installed
+	 */
+	public static function checkDependencies() {
+		if (function_exists('curl_init')) {
+			return true;
+		} else {
+			return array('curl');
+		}
 	}
 
 }
