@@ -1,11 +1,12 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Salva",
-"Search:" => "Ricerca:",
+"Search" => "Cerca",
 "Close" => "Chiudi",
 "Next" => "Successivo",
 "Clear" => "Cancella",
 "Saving..." => "Salvataggio in corso...",
 "Failed to save file" => "Salvataggio del file non riuscito",
 "An error occurred!" => "Si è verificato un errore!",
+"There are unsaved changes in the text editor" => "Ci sono delle modifiche non salvate nell'editor di testo",
 "There were unsaved changes, click here to go back" => "C'erano delle modifiche non salvate, fai clic qui per tornare indietro"
 );
