@@ -2,13 +2,13 @@
 $TRANSLATIONS = array(
 "Couldn't delete %s permanently" => "No s'ha pogut esborrar permanentment %s",
 "Couldn't restore %s" => "No s'ha pogut restaurar %s",
+"Deleted files" => "Fitxers esborrats",
+"Restore" => "Recupera",
 "Error" => "Error",
 "restored" => "restaurat",
 "Nothing in here. Your trash bin is empty!" => "La paperera està buida!",
 "Name" => "Nom",
-"Restore" => "Recupera",
 "Deleted" => "Eliminat",
-"Delete" => "Esborra",
-"Deleted Files" => "Fitxers eliminats"
+"Delete" => "Esborra"
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
