@@ -34,12 +34,13 @@ var videoViewer = {
 				size = {width: 320, height: 240};
 			}
 			return size;
-		},
+		}
 	},
 	mime : null,
 	file : null,
 	location : null,
 	player : null,
+	dir: null,
 	mimeTypes : [
 		'video/mp4',
 		'video/webm',
@@ -51,10 +52,11 @@ var videoViewer = {
 		'video/x-matroska',
 		'video/x-ms-asf'
 	],
-	onView : function(file) {
+	onView : function(file, data) {
 		videoViewer.file = file;
-		videoViewer.location = videoViewer.getMediaUrl(file);
-		videoViewer.mime = FileActions.getCurrentMimeType();
+		videoViewer.dir = data.dir;
+		videoViewer.location = data.fileList.getDownloadUrl(file, videoViewer.dir);
+		videoViewer.mime = data.$file.attr('data-mime');
 		
 		OC.addScript('files_videoviewer','mediaelement-and-player', function(){
 			OC.addScript('files_videoviewer','mep-extra', videoViewer.showPlayer);
@@ -86,10 +88,6 @@ var videoViewer = {
 
 		videoViewer.UI.hide();
 	},
-	getMediaUrl : function(file) {
-		var dir = $('#dir').val();
-		return fileDownloadPath(dir, file);
-	},
 	onKeyDown : function(e) {
 		if (e.keyCode == 27 && !$('.mejs-container-fullscreen').length && videoViewer.player) {
 			 videoViewer.hidePlayer();
@@ -101,11 +99,14 @@ var videoViewer = {
 };
 
 $(document).ready(function() {	
-	if (typeof FileActions !== 'undefined') {
+	if ( typeof OCA !== 'undefined'
+		&& typeof OCA.Files !== 'undefined'
+		&& typeof OCA.Files.fileActions !== 'undefined'
+	) {
 		for (var i = 0; i < videoViewer.mimeTypes.length; ++i) {
 			var mime = videoViewer.mimeTypes[i];
-			FileActions.register(mime, 'View', OC.PERMISSION_READ, '', videoViewer.onView);
-			FileActions.setDefault(mime, 'View');
+			OCA.Files.fileActions.register(mime, 'View', OC.PERMISSION_READ, '', videoViewer.onView);
+			OCA.Files.fileActions.setDefault(mime, 'View');
 		}
 		$(document).keydown(videoViewer.onKeyDown);
 	}
