@@ -23,20 +23,25 @@
 
 namespace OCA\user_ldap\lib;
 
-class Jobs {
+class Jobs extends \OC\BackgroundJob\TimedJob {
 	static private $groupsFromDB;
 
 	static private $groupBE;
 	static private $connector;
 
+	public function __construct(){
+		$this->interval = self::getRefreshInterval();
+	}
+
+	/**
+	 * @param mixed $argument
+	 */
+	public function run($argument){
+		Jobs::updateGroups();
+	}
+
 	static public function updateGroups() {
 		\OCP\Util::writeLog('user_ldap', 'Run background job "updateGroups"', \OCP\Util::DEBUG);
-		$lastUpdate = \OCP\Config::getAppValue('user_ldap', 'bgjUpdateGroupsLastRun', 0);
-		if((time() - $lastUpdate) < self::getRefreshInterval()) {
-			\OCP\Util::writeLog('user_ldap', 'bgJ "updateGroups" – last run too fresh, aborting.', \OCP\Util::DEBUG);
-			//komm runter Werner die Maurer geben ein aus
-			return;
-		}
 
 		$knownGroups = array_keys(self::getKnownGroups());
 		$actualGroups = self::getGroupBE()->getGroups();
@@ -45,7 +50,6 @@ class Jobs {
 			\OCP\Util::writeLog('user_ldap',
 				'bgJ "updateGroups" – groups do not seem to be configured properly, aborting.',
 				\OCP\Util::INFO);
-			\OCP\Config::setAppValue('user_ldap', 'bgjUpdateGroupsLastRun', time());
 			return;
 		}
 
@@ -53,16 +57,20 @@ class Jobs {
 		self::handleCreatedGroups(array_diff($actualGroups, $knownGroups));
 		self::handleRemovedGroups(array_diff($knownGroups, $actualGroups));
 
-		\OCP\Config::setAppValue('user_ldap', 'bgjUpdateGroupsLastRun', time());
-
 		\OCP\Util::writeLog('user_ldap', 'bgJ "updateGroups" – Finished.', \OCP\Util::DEBUG);
 	}
 
+	/**
+	 * @return int
+	 */
 	static private function getRefreshInterval() {
 		//defaults to every hour
 		return \OCP\Config::getAppValue('user_ldap', 'bgjRefreshInterval', 3600);
 	}
 
+	/**
+	 * @param string[] $groups
+	 */
 	static private function handleKnownGroups($groups) {
 		\OCP\Util::writeLog('user_ldap', 'bgJ "updateGroups" – Dealing with known Groups.', \OCP\Util::DEBUG);
 		$query = \OCP\DB::prepare('
@@ -72,32 +80,35 @@ class Jobs {
 		');
 		foreach($groups as $group) {
 			//we assume, that self::$groupsFromDB has been retrieved already
-		    $knownUsers = unserialize(self::$groupsFromDB[$group]['owncloudusers']);
-		    $actualUsers = self::getGroupBE()->usersInGroup($group);
-		    $hasChanged = false;
-		    foreach(array_diff($knownUsers, $actualUsers) as $removedUser) {
-		        \OCP\Util::emitHook('OC_User', 'post_removeFromGroup', array('uid' => $removedUser, 'gid' => $group));
-		        \OCP\Util::writeLog('user_ldap',
+			$knownUsers = unserialize(self::$groupsFromDB[$group]['owncloudusers']);
+			$actualUsers = self::getGroupBE()->usersInGroup($group);
+			$hasChanged = false;
+			foreach(array_diff($knownUsers, $actualUsers) as $removedUser) {
+				\OCP\Util::emitHook('OC_User', 'post_removeFromGroup', array('uid' => $removedUser, 'gid' => $group));
+				\OCP\Util::writeLog('user_ldap',
 				'bgJ "updateGroups" – "'.$removedUser.'" removed from "'.$group.'".',
 				\OCP\Util::INFO);
-		        $hasChanged = true;
-		    }
-		    foreach(array_diff($actualUsers, $knownUsers) as $addedUser) {
-		        \OCP\Util::emitHook('OC_User', 'post_addFromGroup', array('uid' => $addedUser, 'gid' => $group));
-		        \OCP\Util::writeLog('user_ldap',
+				$hasChanged = true;
+			}
+			foreach(array_diff($actualUsers, $knownUsers) as $addedUser) {
+				\OCP\Util::emitHook('OC_User', 'post_addToGroup', array('uid' => $addedUser, 'gid' => $group));
+				\OCP\Util::writeLog('user_ldap',
 				'bgJ "updateGroups" – "'.$addedUser.'" added to "'.$group.'".',
 				\OCP\Util::INFO);
-		        $hasChanged = true;
-		    }
-		    if($hasChanged) {
+				$hasChanged = true;
+			}
+			if($hasChanged) {
 				$query->execute(array(serialize($actualUsers), $group));
-		    }
+			}
 		}
 		\OCP\Util::writeLog('user_ldap',
 			'bgJ "updateGroups" – FINISHED dealing with known Groups.',
 			\OCP\Util::DEBUG);
 	}
 
+	/**
+	 * @param string[] $createdGroups
+	 */
 	static private function handleCreatedGroups($createdGroups) {
 		\OCP\Util::writeLog('user_ldap', 'bgJ "updateGroups" – dealing with created Groups.', \OCP\Util::DEBUG);
 		$query = \OCP\DB::prepare('
@@ -110,13 +121,16 @@ class Jobs {
 				'bgJ "updateGroups" – new group "'.$createdGroup.'" found.',
 				\OCP\Util::INFO);
 			$users = serialize(self::getGroupBE()->usersInGroup($createdGroup));
-		    $query->execute(array($createdGroup, $users));
+			$query->execute(array($createdGroup, $users));
 		}
 		\OCP\Util::writeLog('user_ldap',
 			'bgJ "updateGroups" – FINISHED dealing with created Groups.',
 			\OCP\Util::DEBUG);
 	}
 
+	/**
+	 * @param string[] $removedGroups
+	 */
 	static private function handleRemovedGroups($removedGroups) {
 		\OCP\Util::writeLog('user_ldap', 'bgJ "updateGroups" – dealing with removed groups.', \OCP\Util::DEBUG);
 		$query = \OCP\DB::prepare('
@@ -128,32 +142,43 @@ class Jobs {
 			\OCP\Util::writeLog('user_ldap',
 				'bgJ "updateGroups" – group "'.$removedGroup.'" was removed.',
 				\OCP\Util::INFO);
-		    $query->execute(array($removedGroup));
+			$query->execute(array($removedGroup));
 		}
 		\OCP\Util::writeLog('user_ldap',
 			'bgJ "updateGroups" – FINISHED dealing with removed groups.',
 			\OCP\Util::DEBUG);
 	}
 
-	static private function getConnector() {
-		if(!is_null(self::$connector)) {
-			return self::$connector;
-		}
-		self::$connector = new \OCA\user_ldap\lib\Connection('user_ldap');
-		return self::$connector;
-	}
-
+	/**
+	 * @return \OCA\user_ldap\GROUP_LDAP|\OCA\user_ldap\Group_Proxy
+	 */
 	static private function getGroupBE() {
 		if(!is_null(self::$groupBE)) {
 			return self::$groupBE;
 		}
-		self::getConnector();
-		self::$groupBE = new \OCA\user_ldap\GROUP_LDAP();
-		self::$groupBE->setConnector(self::$connector);
+		$configPrefixes = Helper::getServerConfigurationPrefixes(true);
+		$ldapWrapper = new LDAP();
+		if(count($configPrefixes) === 1) {
+			//avoid the proxy when there is only one LDAP server configured
+			$userManager = new user\Manager(
+				\OC::$server->getConfig(),
+				new FilesystemHelper(),
+				new LogWrapper(),
+				\OC::$server->getAvatarManager(),
+				new \OCP\Image());
+			$connector = new Connection($ldapWrapper, $configPrefixes[0]);
+			$ldapAccess = new Access($connector, $ldapWrapper, $userManager);
+			self::$groupBE = new \OCA\user_ldap\GROUP_LDAP($ldapAccess);
+		} else {
+			self::$groupBE = new \OCA\user_ldap\Group_Proxy($configPrefixes, $ldapWrapper);
+		}
 
 		return self::$groupBE;
 	}
 
+	/**
+	 * @return array
+	 */
 	static private function getKnownGroups() {
 		if(is_array(self::$groupsFromDB)) {
 			return self::$groupsFromDB;
@@ -165,7 +190,7 @@ class Jobs {
 		$result = $query->execute()->fetchAll();
 		self::$groupsFromDB = array();
 		foreach($result as $dataset) {
-		    self::$groupsFromDB[$dataset['owncloudname']] = $dataset;
+			self::$groupsFromDB[$dataset['owncloudname']] = $dataset;
 		}
 
 		return self::$groupsFromDB;
