@@ -1,14 +1,19 @@
 /**
- * @param 'createCallback' A function to be called when a new entry is created. Two arguments are supplied to this function:
- *	The select element used and the value of the option. If the function returns false addition will be cancelled. If it returns
- * 	anything else it will be used as the value of the newly added option.
+ * @param 'createCallback' A function to be called when a new entry is created.
+ *    Two arguments are supplied to this function:
+ *    The select element used and the value of the option. If the function
+ *    returns false addition will be cancelled. If it returns
+ *    anything else it will be used as the value of the newly added option.
  * @param 'createText' The placeholder text for the create action.
  * @param 'title' The title to show if no options are selected.
- * @param 'checked' An array containing values for options that should be checked. Any options which are already selected will be added to this array.
+ * @param 'checked' An array containing values for options that should be
+ *    checked. Any options which are already selected will be added to this array.
  * @param 'labels' The corresponding labels to show for the checked items.
- * @param 'oncheck' Callback function which will be called when a checkbox/radiobutton is selected. If the function returns false the input will be unchecked.
+ * @param 'oncheck' Callback function which will be called when a
+ *    checkbox/radiobutton is selected. If the function returns false the input will be unchecked.
  * @param 'onuncheck' @see 'oncheck'.
- * @param 'singleSelect' If true radiobuttons will be used instead of checkboxes. 
+ * @param 'singleSelect' If true radiobuttons will be used instead of
+ *    checkboxes.
  */
 (function( $ ){
 	var multiSelectId=-1;
@@ -27,16 +32,23 @@
 			'onuncheck':false,
 			'minWidth': 'default;'
 		};
+		var slideDuration = 200;
 		$(this).attr('data-msid', multiSelectId);
 		$.extend(settings,options);
 		$.each(this.children(),function(i,option) {
 			// If the option is selected, but not in the checked array, add it.
-			if($(option).attr('selected') && settings.checked.indexOf($(option).val()) === -1) {
+			if (
+				$(option).attr('selected') &&
+				settings.checked.indexOf($(option).val()) === -1
+			) {
 				settings.checked.push($(option).val());
 				settings.labels.push($(option).text().trim());
 			}
 			// If the option is in the checked array but not selected, select it.
-			else if(settings.checked.indexOf($(option).val()) !== -1 && !$(option).attr('selected')) {
+			else if (
+				settings.checked.indexOf($(option).val()) !== -1 &&
+				!$(option).attr('selected')
+			) {
 				$(option).attr('selected', 'selected');
 				settings.labels.push($(option).text().trim());
 			}
@@ -68,12 +80,12 @@
 			var button=$(this);
 			if(button.parent().children('ul').length>0) {
 				if(self.menuDirection === 'down') {
-					button.parent().children('ul').slideUp(400,function() {
+					button.parent().children('ul').slideUp(slideDuration,function() {
 						button.parent().children('ul').remove();
 						button.removeClass('active down');
 					});
 				} else {
-					button.parent().children('ul').fadeOut(400,function() {
+					button.parent().children('ul').fadeOut(slideDuration,function() {
 						button.parent().children('ul').remove();
 						button.removeClass('active up');
 					});
@@ -81,7 +93,7 @@
 				return;
 			}
 			var lists=$('ul.multiselectoptions');
-			lists.slideUp(400,function(){
+			lists.slideUp(slideDuration,function(){
 				lists.remove();
 				$('div.multiselect').removeClass('active');
 				button.addClass('active');
@@ -103,7 +115,7 @@
 				var label=$('<label/>');
 				label.attr('for',id);
 				label.text(element.text() || item);
-				if(settings.checked.indexOf(item)!=-1 || checked) {
+				if(settings.checked.indexOf(item) !== -1 || checked) {
 					input.attr('checked', true);
 				}
 				if(checked){
@@ -150,17 +162,21 @@
 						settings.labels.splice(index,1);
 					}
 					var oldWidth=button.width();
-					button.children('span').first().text(settings.labels.length > 0 
+					button.children('span').first().text(settings.labels.length > 0
 						? settings.labels.join(', ')
 						: settings.title);
-					var newOuterWidth=Math.max((button.outerWidth()-2),settings.minOuterWidth)+'px';
+					var newOuterWidth = Math.max(
+						(button.outerWidth() - 2),
+						settings.minOuterWidth
+					) + 'px';
 					var newWidth=Math.max(button.width(),settings.minWidth);
 					var pos=button.position();
 					button.css('width',oldWidth);
 					button.animate({'width':newWidth},undefined,undefined,function(){
 						button.css('width','');
 					});
-					list.animate({'width':newOuterWidth,'left':pos.left+3});
+					list.animate({'width':newOuterWidth,'left':pos.left});
+					self.change();
 				});
 				var li=$('<li></li>');
 				li.append(input).append(label);
@@ -183,7 +199,7 @@
 					input.css('width',button.innerWidth());
 					button.parent().data('preventHide',true);
 					input.keypress(function(event) {
-						if(event.keyCode == 13) {
+						if(event.keyCode === 13) {
 							event.preventDefault();
 							event.stopPropagation();
 							var value = $(this).val();
@@ -221,7 +237,7 @@
 							select.append(option);
 							li.prev().children('input').prop('checked', true).trigger('change');
 							button.parent().data('preventHide',false);
-							button.children('span').first().text(settings.labels.length > 0 
+							button.children('span').first().text(settings.labels.length > 0
 								? settings.labels.join(', ')
 								: settings.title);
 							if(self.menuDirection === 'up') {
@@ -264,24 +280,24 @@
 			}
 			list.append(list.find('li.creator'));
 			var pos=button.position();
-			if(($(document).height() > (button.offset().top+button.outerHeight() + list.children().length * button.height())
-				&& $(document).height() - button.offset().top > (button.offset().top+button.outerHeight() + list.children().length * button.height()))
-				|| $(document).height()/2 > button.offset().top
+			if(($(document).height() > (button.offset().top + button.outerHeight() + list.children().length * button.height()) &&
+				$(document).height() - button.offset().top > (button.offset().top+button.outerHeight() + list.children().length * button.height())) ||
+				$(document).height() / 2 > button.offset().top
 			) {
 				list.css({
 					top:pos.top+button.outerHeight()-5,
-					left:pos.left+3,
+					left:pos.left,
 					width:(button.outerWidth()-2)+'px',
 					'max-height':($(document).height()-(button.offset().top+button.outerHeight()+10))+'px'
 				});
 				list.addClass('down');
 				button.addClass('down');
-				list.slideDown();
+				list.slideDown(slideDuration);
 			} else {
 				list.css('max-height', $(document).height()-($(document).height()-(pos.top)+50)+'px');
 				list.css({
 					top:pos.top - list.height(),
-					left:pos.left+3,
+					left:pos.left,
 					width:(button.outerWidth()-2)+'px'
 					
 				});
@@ -299,12 +315,12 @@
 			if(!button.parent().data('preventHide')) {
 				// How can I save the effect in a var?
 				if(self.menuDirection === 'down') {
-					button.parent().children('ul').slideUp(400,function() {
+					button.parent().children('ul').slideUp(slideDuration,function() {
 						button.parent().children('ul').remove();
 						button.removeClass('active down');
 					});
 				} else {
-					button.parent().children('ul').fadeOut(400,function() {
+					button.parent().children('ul').fadeOut(slideDuration,function() {
 						button.parent().children('ul').remove();
 						button.removeClass('active up');
 					});
