@@ -1,6 +1,5 @@
-<?php $TRANSLATIONS = array(
-"No category to add?" => "Nemate kategorija koje možete dodati?",
-"No categories selected for deletion." => "Nema odabranih kategorija za brisanje.",
+<?php
+$TRANSLATIONS = array(
 "Sunday" => "nedelja",
 "Monday" => "ponedeljak",
 "Tuesday" => "utorak",
@@ -21,27 +20,31 @@
 "November" => "Studeni",
 "December" => "Prosinac",
 "Settings" => "Postavke",
+"Folder" => "mapa",
+"Saving..." => "Spremanje...",
 "seconds ago" => "sekundi prije",
+"_%n minute ago_::_%n minutes ago_" => array("","",""),
+"_%n hour ago_::_%n hours ago_" => array("","",""),
 "today" => "danas",
 "yesterday" => "jučer",
+"_%n day ago_::_%n days ago_" => array("","",""),
 "last month" => "prošli mjesec",
-"months ago" => "mjeseci",
+"_%n month ago_::_%n months ago_" => array("","",""),
 "last year" => "prošlu godinu",
 "years ago" => "godina",
-"Choose" => "Izaberi",
-"Cancel" => "Odustani",
-"No" => "Ne",
+"Reset password" => "Poništavanje lozinke",
 "Yes" => "Da",
+"No" => "Ne",
+"Choose" => "Izaberi",
 "Ok" => "U redu",
-"Error" => "Pogreška",
+"_{count} file conflict_::_{count} file conflicts_" => array("","",""),
+"Cancel" => "Odustani",
 "Share" => "Podijeli",
+"Error" => "Greška",
 "Error while sharing" => "Greška prilikom djeljenja",
 "Error while unsharing" => "Greška prilikom isključivanja djeljenja",
 "Error while changing permissions" => "Greška prilikom promjena prava",
-"Share with" => "Djeli sa",
-"Share with link" => "Djeli preko link-a",
 "Password protect" => "Zaštiti lozinkom",
-"Password" => "Lozinka",
 "Set expiration date" => "Postavi datum isteka",
 "Expiration date" => "Datum isteka",
 "Share via email:" => "Dijeli preko email-a:",
@@ -53,19 +56,15 @@
 "create" => "kreiraj",
 "update" => "ažuriraj",
 "delete" => "izbriši",
-"share" => "djeli",
 "Password protected" => "Zaštita lozinkom",
 "Error unsetting expiration date" => "Greška prilikom brisanja datuma isteka",
 "Error setting expiration date" => "Greška prilikom postavljanja datuma isteka",
-"ownCloud password reset" => "ownCloud resetiranje lozinke",
+"Delete" => "Obriši",
+"Add" => "Dodaj",
 "Use the following link to reset your password: {link}" => "Koristite ovaj link da biste poništili lozinku: {link}",
 "You will receive a link to reset your password via Email." => "Primit ćete link kako biste poništili zaporku putem e-maila.",
 "Username" => "Korisničko ime",
-"Request reset" => "Zahtjev za resetiranjem",
-"Your password was reset" => "Vaša lozinka je resetirana",
-"To login page" => "Idi na stranicu za prijavu",
 "New password" => "Nova lozinka",
-"Reset password" => "Poništavanje lozinke",
 "Personal" => "Osobno",
 "Users" => "Korisnici",
 "Apps" => "Aplikacije",
@@ -73,24 +72,18 @@
 "Help" => "Pomoć",
 "Access forbidden" => "Pristup zabranjen",
 "Cloud not found" => "Cloud nije pronađen",
-"Edit categories" => "Uredi kategorije",
-"Add" => "Dodaj",
 "Create an <strong>admin account</strong>" => "Stvori <strong>administratorski račun</strong>",
-"Advanced" => "Dodatno",
+"Password" => "Lozinka",
 "Data folder" => "Mapa baze podataka",
 "Configure the database" => "Konfiguriraj bazu podataka",
-"will be used" => "će se koristiti",
 "Database user" => "Korisnik baze podataka",
 "Database password" => "Lozinka baze podataka",
 "Database name" => "Ime baze podataka",
 "Database tablespace" => "Database tablespace",
 "Database host" => "Poslužitelj baze podataka",
 "Finish setup" => "Završi postavljanje",
-"web services under your control" => "web usluge pod vašom kontrolom",
 "Log out" => "Odjava",
-"Lost your password?" => "Izgubili ste lozinku?",
 "remember" => "zapamtiti",
-"Log in" => "Prijava",
-"prev" => "prethodan",
-"next" => "sljedeći"
+"Log in" => "Prijava"
 );
+$PLURAL_FORMS = "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;";
