@@ -21,17 +21,15 @@
 *
 */
 
-
-// Init owncloud
-require_once '../../lib/base.php';
-
 // Check if we are a user
 OC_JSON::checkLoggedIn();
+\OC::$server->getSession()->close();
 
 $query=(isset($_GET['query']))?$_GET['query']:'';
 if($query) {
-	$result=OC_Search::search($query);
+	$result = \OC::$server->getSearch()->search($query);
 	OC_JSON::encodedPrint($result);
-}else{
+}
+else {
 	echo 'false';
 }
