@@ -10,8 +10,9 @@ OC_App::loadApp('files_encryption');
 $params = array('uid' => \OCP\User::getUser(),
 				'password' => $_POST['password']);
 
-$view = new OC_FilesystemView('/');
+$view = new OC\Files\View('/');
 $util = new \OCA\Encryption\Util($view, \OCP\User::getUser());
+$l = \OC_L10N::get('settings');
 
 $result = $util->initEncryption($params);
 
@@ -27,11 +28,11 @@ if ($result !== false) {
 	$util->closeEncryptionSession();
 
 	if ($successful === true) {
-		\OCP\JSON::success(array('data' => array('message' => 'Files decrypted successfully')));
+		\OCP\JSON::success(array('data' => array('message' => $l->t('Files decrypted successfully'))));
 	} else {
-		\OCP\JSON::error(array('data' => array('message' => 'Couldn\'t decrypt your files, please check your owncloud.log or ask your administrator')));
+		\OCP\JSON::error(array('data' => array('message' => $l->t('Couldn\'t decrypt your files, please check your owncloud.log or ask your administrator'))));
 	}
 } else {
-	\OCP\JSON::error(array('data' => array('message' => 'Couldn\'t decrypt your files, check your password and try again')));
+	\OCP\JSON::error(array('data' => array('message' => $l->t('Couldn\'t decrypt your files, check your password and try again'))));
 }
 
