@@ -1,32 +1,41 @@
-<?php $TRANSLATIONS = array(
-"OpenID Changed" => "OpenID cambiate",
-"Invalid request" => "Requesta invalide",
+<?php
+$TRANSLATIONS = array(
+"Email sent" => "Message de e-posta inviate",
 "Language changed" => "Linguage cambiate",
+"Invalid request" => "Requesta invalide",
+"Error" => "Error",
+"Update" => "Actualisar",
+"Very weak password" => "Contrasigno multo debile",
+"Weak password" => "Contrasigno debile",
+"So-so password" => "Contrasigno passabile",
+"Good password" => "Contrasigno bon",
+"Strong password" => "Contrasigno forte",
+"Groups" => "Gruppos",
+"Delete" => "Deler",
+"never" => "nunquam",
 "__language_name__" => "Interlingua",
+"Security Warning" => "Aviso de securitate",
 "Log" => "Registro",
 "More" => "Plus",
 "Add your App" => "Adder tu application",
 "Select an App" => "Selectionar un app",
-"Documentation" => "Documentation",
-"Ask a question" => "Facer un question",
-"Answer" => "Responsa",
-"Download" => "Discargar",
+"Get the apps to sync your files" => "Obtene le apps (applicationes) pro synchronizar tu files",
+"Password" => "Contrasigno",
 "Unable to change your password" => "Non pote cambiar tu contrasigno",
 "Current password" => "Contrasigno currente",
 "New password" => "Nove contrasigno",
-"show" => "monstrar",
 "Change password" => "Cambiar contrasigno",
 "Email" => "E-posta",
 "Your email address" => "Tu adresse de e-posta",
+"Profile picture" => "Imagine de profilo",
+"Cancel" => "Cancellar",
 "Language" => "Linguage",
 "Help translate" => "Adjuta a traducer",
-"use this address to connect to your ownCloud in your file manager" => "usa iste addresse pro connecter a tu ownCloud in tu administrator de files",
-"Name" => "Nomine",
-"Password" => "Contrasigno",
-"Groups" => "Gruppos",
 "Create" => "Crear",
+"Group" => "Gruppo",
 "Default Quota" => "Quota predeterminate",
 "Other" => "Altere",
-"Quota" => "Quota",
-"Delete" => "Deler"
+"Username" => "Nomine de usator",
+"Quota" => "Quota"
 );
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
