@@ -1,54 +1,57 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
+"Email sent" => "Email geschéckt",
 "Unable to load list from App Store" => "Konnt Lescht net vum App Store lueden",
 "Authentication error" => "Authentifikatioun's Fehler",
+"Group already exists" => "Group existeiert schon.",
+"Unable to add group" => "Onmeiglech Grupp beizefügen.",
 "Email saved" => "E-mail gespäichert",
 "Invalid email" => "Ongülteg e-mail",
-"OpenID Changed" => "OpenID huet geännert",
-"Invalid request" => "Ongülteg Requête",
+"Unable to delete group" => "Onmeiglech d'Grup ze läschen.",
+"Unable to delete user" => "Onmeiglech User zu läschen.",
 "Language changed" => "Sprooch huet geännert",
+"Invalid request" => "Ongülteg Requête",
+"Admins can't remove themself from the admin group" => "Admins kennen sech selwer net aus enger Admin Group läschen.",
+"Unable to add user to group %s" => "Onmeiglech User an Grupp ze sätzen %s",
 "Disable" => "Ofschalten",
 "Enable" => "Aschalten",
-"Saving..." => "Speicheren...",
+"Error" => "Fehler",
+"Update" => "Update",
+"undo" => "réckgängeg man",
+"Groups" => "Gruppen",
+"Group Admin" => "Gruppen Admin",
+"Delete" => "Läschen",
+"never" => "ni",
 "__language_name__" => "__language_name__",
+"Login" => "Login",
 "Security Warning" => "Sécherheets Warnung",
 "Cron" => "Cron",
-"Enable Share API" => "Share API aschalten",
 "Allow apps to use the Share API" => "Erlab Apps d'Share API ze benotzen",
-"Allow links" => "Links erlaben",
 "Allow resharing" => "Resharing erlaben",
-"Allow users to share with anyone" => "Useren erlaben mat egal wiem ze sharen",
-"Allow users to only share with users in their groups" => "Useren nëmmen erlaben mat Useren aus hirer Grupp ze sharen",
+"Server address" => "Server Adress",
 "Log" => "Log",
 "More" => "Méi",
+"Less" => "Manner",
 "Add your App" => "Setz deng App bei",
 "Select an App" => "Wiel eng Applikatioun aus",
 "See application page at apps.owncloud.com" => "Kuck dir d'Applicatioun's Säit op apps.owncloud.com un",
-"Documentation" => "Dokumentatioun",
-"Managing Big Files" => "Grouss Fichieren verwalten",
-"Ask a question" => "Stell eng Fro",
-"Problems connecting to help database." => "Problemer sinn opgetrueden beim Versuch sech un d'Hëllef Datebank ze verbannen.",
-"Go there manually." => "Gei manuell dohinner.",
-"Answer" => "Äntwert",
-"Desktop and Mobile Syncing Clients" => "Desktop an Mobile Syncing Clienten",
-"Download" => "Download",
+"All" => "All",
+"Password" => "Passwuert",
 "Unable to change your password" => "Konnt däin Passwuert net änneren",
 "Current password" => "Momentan 't Passwuert",
 "New password" => "Neit Passwuert",
-"show" => "weisen",
 "Change password" => "Passwuert änneren",
 "Email" => "Email",
 "Your email address" => "Deng Email Adress",
-"Fill in an email address to enable password recovery" => "Gëff eng Email Adress an fir d'Passwuert recovery ze erlaben",
+"Cancel" => "Ofbriechen",
 "Language" => "Sprooch",
 "Help translate" => "Hëllef iwwersetzen",
-"use this address to connect to your ownCloud in your file manager" => "benotz dës Adress fir dech un deng ownCloud iwwert däin Datei Manager ze verbannen",
-"Name" => "Numm",
-"Password" => "Passwuert",
-"Groups" => "Gruppen",
+"Login Name" => "Login",
 "Create" => "Erstellen",
+"Group" => "Grupp",
 "Default Quota" => "Standard Quota",
 "Other" => "Aner",
-"Group Admin" => "Gruppen Admin",
-"Quota" => "Quota",
-"Delete" => "Läschen"
+"Username" => "Benotzernumm",
+"Quota" => "Quota"
 );
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
