@@ -1,45 +1,43 @@
-<?php $TRANSLATIONS = array(
+<?php
+$TRANSLATIONS = array(
 "Authentication error" => "Ralat pengesahan",
 "Email saved" => "Emel disimpan",
 "Invalid email" => "Emel tidak sah",
-"OpenID Changed" => "OpenID diubah",
-"Invalid request" => "Permintaan tidak sah",
 "Language changed" => "Bahasa diubah",
+"Invalid request" => "Permintaan tidak sah",
 "Disable" => "Nyahaktif",
 "Enable" => "Aktif",
-"Saving..." => "Simpan...",
+"Error" => "Ralat",
+"Update" => "Kemaskini",
+"Groups" => "Kumpulan",
+"Delete" => "Padam",
+"never" => "jangan",
 "__language_name__" => "_nama_bahasa_",
+"Login" => "Log masuk",
 "Security Warning" => "Amaran keselamatan",
+"Server address" => "Alamat pelayan",
 "Log" => "Log",
+"Log level" => "Tahap Log",
 "More" => "Lanjutan",
 "Add your App" => "Tambah apps anda",
 "Select an App" => "Pilih aplikasi",
 "See application page at apps.owncloud.com" => "Lihat halaman applikasi di apps.owncloud.com",
-"Documentation" => "Dokumentasi",
-"Managing Big Files" => "Mengurus Fail Besar",
-"Ask a question" => "Tanya soalan",
-"Problems connecting to help database." => "Masalah menghubung untuk membantu pengkalan data",
-"Go there manually." => "Pergi ke sana secara manual",
-"Answer" => "Jawapan",
-"Desktop and Mobile Syncing Clients" => "Klien Selarian untuk Desktop dan Mobile",
-"Download" => "Muat turun",
+"Password" => "Kata laluan",
 "Unable to change your password" => "Gagal mengubah kata laluan anda ",
 "Current password" => "Kata laluan semasa",
 "New password" => "Kata laluan baru",
-"show" => "Papar",
 "Change password" => "Ubah kata laluan",
-"Email" => "Emel",
+"Email" => "Email",
 "Your email address" => "Alamat emel anda",
-"Fill in an email address to enable password recovery" => "Isi alamat emel anda untuk membolehkan pemulihan kata laluan",
+"Profile picture" => "Gambar profil",
+"Cancel" => "Batal",
 "Language" => "Bahasa",
 "Help translate" => "Bantu terjemah",
-"use this address to connect to your ownCloud in your file manager" => "guna alamat ini untuk menyambung owncloud anda dalam pengurus fail anda",
-"Name" => "Nama",
-"Password" => "Kata laluan ",
-"Groups" => "Kumpulan",
+"Login Name" => "Log masuk",
 "Create" => "Buat",
 "Default Quota" => "Kuota Lalai",
 "Other" => "Lain",
-"Quota" => "Kuota",
-"Delete" => "Padam"
+"Username" => "Nama pengguna",
+"Quota" => "Kuota"
 );
+$PLURAL_FORMS = "nplurals=1; plural=0;";
